<!---
	COMPONENT: ContactGateway
	AUTHOR: Matt Woodward (mpwoodward@gmail.com)
	DATE: 7/17/2005
	PURPOSE: Contact Gateway for Mach-II Contact Manager sample application
	CHANGE HISTORY:
		* 2/28/2006: component created (Matt Woodward)
--->

<cfcomponent displayname="ContactGateway" output="false" hint="ContactGateway for Mach-II Contact Manager Sample Application">
	<cffunction name="init" access="public" output="false" returntype="ContactGateway" hint="Constructor for this CFC">
		<!--- take in the datasource name as an argument and set it to the variables scope so it's available 
				throughout the CFC --->
		<cfargument name="dsn" type="string" required="true" />
		<cfset variables.dsn = arguments.dsn />
		
		<!--- return the object itself --->
		<cfreturn this />
	</cffunction>
	
	<cffunction name="getAllContacts" access="public" output="false" returntype="query" 
			hint="Returns all the contacts in the database">
		<!--- var scope the query before running it! --->
		<cfset var getContacts = "" />
		
		<!--- run the query and return it --->
		<cfquery name="getContacts" datasource="#variables.dsn#">
			SELECT * 
			FROM contact 
			ORDER BY last_name, first_name
		</cfquery>
		
		<cfreturn getContacts />
	</cffunction>
	
	<cffunction name="getRecentContacts" access="public" output="false" returntype="query" 
			hint="Returns the three most recent contacts entered into the database">
		<cfset var getContacts = "" />
		
		<!--- in order to make this compatible with both SQL Server and MySQL, I'm just using maxrows 
				as opposed to TOP or LIMIT in the query --->
		<cfquery name="getContacts" datasource="#variables.dsn#" maxrows="3">
			SELECT * 
			FROM contact 
			ORDER BY dt_created DESC
		</cfquery>
		
		<cfreturn getContacts />
	</cffunction>
</cfcomponent>